@@ -402,13 +402,13 @@ build_table(charpick_data *p_curr_data)
 {
   GtkWidget *box, *button_box, **row_box;
   GtkWidget *button, *arrow;
-  GtkTooltips *tooltips;
   gint i = 0, len = g_utf8_strlen (p_curr_data->charlist, -1);
-  GtkWidget *toggle_button[len];
+  GtkWidget **toggle_button;
   gchar *charlist;
   gint max_width=1, max_height=1;
   gint size_ratio;
 
+  toggle_button = g_new (GtkWidget *, len);
   
   if (p_curr_data->box)
     gtk_widget_destroy(p_curr_data->box);
@@ -420,11 +420,10 @@ build_table(charpick_data *p_curr_data)
   gtk_widget_show (box);
   p_curr_data->box = box;
   
-  tooltips = gtk_tooltips_new ();  
   button = gtk_button_new ();
   if (g_list_length (p_curr_data->chartable) != 1)
   {
-    gtk_tooltips_set_tip (tooltips, button, _("Available palettes"), NULL);
+    gtk_widget_set_tooltip_text (button, _("Available palettes"));
   
     switch (panel_applet_get_orient (PANEL_APPLET (p_curr_data->applet))) {
        	case PANEL_APPLET_ORIENT_DOWN:
@@ -460,7 +459,7 @@ build_table(charpick_data *p_curr_data)
   for (i = 0; i < len; i++) {
     gchar label[7];
     GtkRequisition req;
-    gchar atk_desc[50];
+    gchar *atk_desc;
     gchar *name;
     
     g_utf8_strncpy (label, charlist, 1);
@@ -478,13 +477,14 @@ build_table(charpick_data *p_curr_data)
 #endif
    
     toggle_button[i] = gtk_toggle_button_new_with_label (label);
-    sprintf(atk_desc, _("insert special character %s"), label);
+    atk_desc =  g_strdup_printf (_("insert special character %s"), label);
     set_atk_name_description (toggle_button[i], NULL, atk_desc);
+    g_free (atk_desc);
     gtk_widget_show (toggle_button[i]);
     gtk_button_set_relief(GTK_BUTTON(toggle_button[i]), GTK_RELIEF_NONE);
     /* FIXME : evil hack (see force_no_focus_padding) */
     force_no_focus_padding (toggle_button[i]);
-    gtk_tooltips_set_tip (tooltips, toggle_button[i], name, NULL);
+    gtk_widget_set_tooltip_text (toggle_button[i], name);
     g_free (name);
                       
     gtk_widget_size_request (toggle_button[i], &req);
@@ -532,6 +532,8 @@ build_table(charpick_data *p_curr_data)
   	gtk_box_pack_start (GTK_BOX (row_box[index]), toggle_button[i], TRUE, TRUE, 0);
   }
  
+  g_free (toggle_button);
+  
   gtk_container_add (GTK_CONTAINER(p_curr_data->applet), box);
   gtk_widget_show_all (p_curr_data->box);
 
@@ -588,7 +590,6 @@ about (BonoboUIComponent *uic,
   };
 
   gtk_show_about_dialog (NULL,
-	"name",		_("Character Palette"),
 	"version",	VERSION,
 	"copyright",	"\xC2\xA9 1998, 2004-2005 GNOME Applets Maintainers "
 			"and others",
@@ -738,6 +739,8 @@ charpicker_applet_fill (PanelApplet *applet)
   GdkAtom utf8_atom;
   GList *list;
   gchar *string;
+
+  g_set_application_name (_("Character Palette"));
   
   gtk_window_set_default_icon_name ("charpick");
   
