@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c 10505 2007-11-04 02:25:35Z callum $ */
+/* $Id: gweather-pref.c 10529 2007-11-22 07:59:29Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -31,6 +31,8 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
+#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
+
 #include "gweather.h"
 #include "gweather-pref.h"
 #include "gweather-applet.h"
@@ -784,7 +786,7 @@ gweather_pref_create (GWeatherPref *pref)
     gtk_dialog_set_default_response (GTK_DIALOG (pref), GTK_RESPONSE_CLOSE);
     gtk_dialog_set_has_separator (GTK_DIALOG (pref), FALSE);
     gtk_container_set_border_width (GTK_CONTAINER (pref), 5);
-    gtk_window_set_resizable (GTK_WINDOW (pref), FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (pref), TRUE);
     gtk_window_set_screen (GTK_WINDOW (pref),
 			   gtk_widget_get_screen (GTK_WIDGET (pref->priv->applet->applet)));
 
